@@ -2,7 +2,7 @@ use 5.14.0;
 
 package Map::Metro::Plugin::Map::Lille;
 
-our $VERSION = '0.1000'; # VERSION
+our $VERSION = '0.1001'; # VERSION
 # ABSTRACT: Map::Metro map for Lille
 
 use Moose;
@@ -26,6 +26,14 @@ __END__
 
 =encoding utf-8
 
+=head1 NAME
+
+Map::Metro::Plugin::Map::Lille - Map::Metro map for Lille
+
+=head1 VERSION
+
+Version 0.1001, released 2015-01-09.
+
 =head1 SYNOPSIS
 
     use Map::Metro;
@@ -45,9 +53,33 @@ L<Map::Metro::Plugin::Map::Lille::Lines>
 
 This map includes:
 
-=for :list
-* The two metro lines [L<wikipedia|https://en.wikipedia.org/wiki/Lille_Metro>]
+=over 4
+
+=item *
+
+The two metro lines [L<wikipedia|https://en.wikipedia.org/wiki/Lille_Metro>]
+
+=back
 
 =for HTML <p><a href="https://raw.githubusercontent.com/Csson/p5-Map-Metro-Lille/master/static/images/lille.png"><img src="https://raw.githubusercontent.com/Csson/p5-Map-Metro-Lille/master/static/images/lille.png" style="max-width: 600px" /></a></p>
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Map-Metro-Lille>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Map-Metro-Plugin-Map-Lille>
+
+=head1 AUTHOR
+
+Erik Carlsson <info@code301.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
